@@ -2,4 +2,4 @@ from genz_tokenize.tokenize import Tokenize
 from genz_tokenize.tokenize import TokenizeForBert
 from genz_tokenize.tokenize import get_embedding_matrix
 from genz_tokenize import preprocess
-from genz_tokenize import models
+from genz_tokenize import models, training, utils
